
Some gui utilities using the silx library from http//github.com/silx-kit/silx

# silx_colfile.py 

Load / save columnfile, choose axes to plot, apply masking operations.

# silx_sptview.py

Display peak search output (sptfile) overlaying image and spots

- crashes on exit on windows, bug or PyQT feature?

# silx_plot3d.py 

Displays a 3D plot of g-vectors

- opengl not working at beamline (ESRF rnice to debian 8 desktop)
